Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(770)

Unified Diff: sky/sdk/lib/widgets/animated_container.dart

Issue 1233703003: add initState, rename animated_container (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: remove print statement Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sky/sdk/lib/widgets/animated_container.dart
diff --git a/sky/sdk/lib/widgets/animated_container.dart b/sky/sdk/lib/widgets/animated_container.dart
index 89a5a0cb1941cf62df6a67c969c720a323990f50..4a42a530ff9c022e6d6cb297b3fe71778d77b25e 100644
--- a/sky/sdk/lib/widgets/animated_container.dart
+++ b/sky/sdk/lib/widgets/animated_container.dart
@@ -11,23 +11,23 @@ import '../painting/box_painter.dart';
import '../theme/shadows.dart';
import 'basic.dart';
// This class builds a Container object from a collection of optionally-
// animated properties. Use syncFields to update the Container's properties,
// which will optionally animate them using an AnimationPerformance.
-class AnimatedContainer {
+class AnimationBuilder {
AnimatedType<double> opacity;
AnimatedType<Point> position;
AnimatedType<double> shadow;
AnimatedColor backgroundColor;
// These don't animate, but are used to build the Container anyway.
double borderRadius;
Shape shape;
Map<AnimatedVariable, AnimationPerformance> _variableToPerformance =
new Map<AnimatedVariable, AnimationPerformance>();
- AnimatedContainer();
+ AnimationBuilder();
AnimationPerformance createPerformance(List<AnimatedType> variables,
{Duration duration}) {
@@ -65,7 +65,7 @@ class AnimatedContainer {
return current;
}
- void syncFields(AnimatedContainer source) {
+ void syncFields(AnimationBuilder source) {
_syncField(position, source.position);
_syncField(shadow, source.shadow);
_syncField(backgroundColor, source.backgroundColor);
@@ -11,23 +11,23 @@ import '../painting/box_painter.dart';
import '../theme/shadows.dart';
import 'basic.dart';
-// This class builds a Container object from a collection of optionally-
-// animated properties. Use syncFields to update the Container's properties,
+// This class builds a Builder object from a collection of optionally-
+// animated properties. Use syncFields to update the Builder's properties,
// which will optionally animate them using an AnimationPerformance.
@@ -11,23 +11,23 @@ import '../painting/box_painter.dart';
AnimatedType<double> shadow;
AnimatedColor backgroundColor;
- // These don't animate, but are used to build the Container anyway.
+ // These don't animate, but are used to build the AnimationBuilder anyway.
double borderRadius;
Shape shape;

Powered by Google App Engine
This is Rietveld 408576698